@@ -43,12 +43,12 @@ QString FilterBalsa::isMailerFound()
 
 QString FilterBalsa::defaultSettingsPath()
 {
-    return QDir::homePath() + QLatin1String("/.balsa/");
+    return QDir::homePath() + QLatin1StringView("/.balsa/");
 }
 
 QString FilterBalsa::localMailDirPath()
 {
-    return QDir::homePath() + QLatin1String("/mail/");
+    return QDir::homePath() + QLatin1StringView("/mail/");
 }
 
 /** Recursive import of KMail maildir. */
@@ -74,7 +74,7 @@ void FilterBalsa::processDirectory(const QString &path)
         if (filterInfo()->shouldTerminate()) {
             break;
         }
-        if (!(*filename == QLatin1Char('.') || *filename == QLatin1String(".."))) {
+        if (!(*filename == QLatin1Char('.') || *filename == QLatin1StringView(".."))) {
             filterInfo()->setCurrent(0);
             importDirContents(dir.filePath(*filename));
             filterInfo()->setOverall((d->mTotalDir > 0) ? (int)((float)d->mImportDirDone / d->mTotalDir * 100) : 0);
@@ -156,9 +156,9 @@ void FilterBalsa::importFiles(const QString &dirName)
             return;
         }
         QString temp_mailfile = *mailFile;
-        if (!(temp_mailfile.endsWith(QLatin1String(".db")) || temp_mailfile.endsWith(QLatin1String(".cmeta"))
-              || temp_mailfile.endsWith(QLatin1String(".ev-summary")) || temp_mailfile.endsWith(QLatin1String(".ibex.index"))
-              || temp_mailfile.endsWith(QLatin1String(".ibex.index.data")))) {
+        if (!(temp_mailfile.endsWith(QLatin1StringView(".db")) || temp_mailfile.endsWith(QLatin1StringView(".cmeta"))
+              || temp_mailfile.endsWith(QLatin1StringView(".ev-summary")) || temp_mailfile.endsWith(QLatin1StringView(".ibex.index"))
+              || temp_mailfile.endsWith(QLatin1StringView(".ibex.index.data")))) {
             if (!generatedPath) {
                 _path = i18nc("define folder name where we import evolution mails", "Evolution-Import");
                 QString _tmp = dir.filePath(*mailFile);
@@ -180,7 +180,7 @@ void FilterBalsa::importFiles(const QString &dirName)
                         _path.replace(QLatin1Char('.'), QLatin1Char('/'));
                     }
                 }
-                if (_path.endsWith(QLatin1String("cur"))) {
+                if (_path.endsWith(QLatin1StringView("cur"))) {
                     _path.remove(_path.length() - 4, 4);
                 }
                 QString _info = _path;
@@ -202,7 +202,7 @@ void FilterBalsa::importFiles(const QString &dirName)
 MailImporter::MessageStatus FilterBalsa::statusFromFile(const QString &filename)
 {
     MailImporter::MessageStatus status;
-    const int statusIndex = filename.indexOf(QLatin1String(":2,"));
+    const int statusIndex = filename.indexOf(QLatin1StringView(":2,"));
     if (statusIndex != -1) {
         const QString statusStr = filename.right(filename.length() - statusIndex - 3);
         if (statusStr.contains(QLatin1Char('S'))) {
