@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_OPERA_H
-#define MAILIMPORTER_FILTER_OPERA_H
+#pragma once
 
 #include "filters.h"
 #include <QDir>
@@ -25,13 +24,11 @@ public:
 
     void import() override;
     void importMails(const QString &maildir);
-    Q_REQUIRED_RESULT static QString defaultSettingsPath();
-    Q_REQUIRED_RESULT static QString isMailerFound();
+    [[nodiscard]] static QString defaultSettingsPath();
+    [[nodiscard]] static QString isMailerFound();
 
 private:
-    void importBox(const QDir &importDir, const QStringList &, const QString &accountName = QString());
-    void importRecursive(const QDir &maildir, const QString &accountName = QString());
+    MAILIMPORTER_NO_EXPORT void importBox(const QDir &importDir, const QStringList &, const QString &accountName = QString());
+    MAILIMPORTER_NO_EXPORT void importRecursive(const QDir &maildir, const QString &accountName = QString());
 };
 }
-
-#endif
